aboutsummaryrefslogtreecommitdiffstats
path: root/syz-ci/syz-ci.go
diff options
context:
space:
mode:
authorAleksandr Nogikh <nogikh@google.com>2024-08-22 15:41:11 +0200
committerAleksandr Nogikh <nogikh@google.com>2024-08-22 17:38:44 +0000
commitce8a9099a5364313c309ba882f76c9ab4d74afb1 (patch)
tree49e493f41dd15ff9e0051decd9c9ad527d2c75f2 /syz-ci/syz-ci.go
parent4d0fcc557324c5d7be71cf7deafa158a4e81ab1c (diff)
all: rename build_jobs to build_cpus
The latter is a better suitable name.
Diffstat (limited to 'syz-ci/syz-ci.go')
-rw-r--r--syz-ci/syz-ci.go4
1 files changed, 2 insertions, 2 deletions
diff --git a/syz-ci/syz-ci.go b/syz-ci/syz-ci.go
index 639a9bb8c..8a970131e 100644
--- a/syz-ci/syz-ci.go
+++ b/syz-ci/syz-ci.go
@@ -126,8 +126,8 @@ type Config struct {
// The list is concatenated with the similar parameter from ManagerConfig.
BisectBackports []vcs.BackportCommit `json:"bisect_backports"`
Ccache string `json:"ccache"`
- // BuildJobs defines the maximum number of parallel kernel build threads.
- BuildJobs int `json:"build_jobs"`
+ // BuildCPUs defines the maximum number of parallel kernel build threads.
+ BuildCPUs int `json:"build_cpus"`
Managers []*ManagerConfig `json:"managers"`
// Poll period for jobs in seconds (optional, defaults to 10 seconds)
JobPollPeriod int `json:"job_poll_period"`